@@ -19,9 +19,9 @@
 
 """Provides the default implementation for flat review for Orca."""
 
-__id__        = "$Id: flat_review.py 1790 2006-12-06 19:12:55Z wwalker $"
-__version__   = "$Revision: 1790 $"
-__date__      = "$Date: 2006-12-06 14:12:55 -0500 (Wed, 06 Dec 2006) $"
+__id__        = "$Id: flat_review.py 1987 2007-02-07 21:27:28Z joanied $"
+__version__   = "$Revision: 1987 $"
+__date__      = "$Date: 2007-02-07 16:27:28 -0500 (Wed, 07 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -399,7 +399,8 @@ class Context:
         currentWordIndex = 0
         currentCharIndex = 0
 
-        if orca_state.locusOfFocus.role == rolenames.ROLE_TABLE_CELL:
+        if orca_state.locusOfFocus and \
+           orca_state.locusOfFocus.role == rolenames.ROLE_TABLE_CELL:
             searchZone = util.getRealActiveDescendant(orca_state.locusOfFocus)
         else:
             searchZone = orca_state.locusOfFocus
