@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2005-2006 Sun Microsystems Inc.
+# Copyright 2005-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -20,9 +20,9 @@
 """Manages the magnifier for orca.  [[[TODO: WDW - this is very very
 early in development.  One might even say it is pre-prototype.]]]"""
 
-__id__        = "$Id: mag.py,v 1.31 2006/09/19 21:30:55 richb Exp $"
-__version__   = "$Revision: 1.31 $"
-__date__      = "$Date: 2006/09/19 21:30:55 $"
+__id__        = "$Id: mag.py 1979 2007-02-04 16:44:37Z wwalker $"
+__version__   = "$Revision: 1979 $"
+__date__      = "$Date: 2007-02-04 11:44:37 -0500 (Sun, 04 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -432,7 +432,7 @@ def applySettings():
     #print "ZOOMER PROPERTIES:", _zoomer
     #__dumpPropertyBag(_zoomer)
 
-def magnifyAccessible(event, obj):
+def magnifyAccessible(event, obj, extents=None):
     """Sets the region of interest to the upper left of the given
     accessible, if it implements the Component interface.  Otherwise,
     does nothing.
@@ -445,7 +445,9 @@ def magnifyAccessible(event, obj):
     if not _initialized:
         return
 
-    if event and (event.type == "object:text-caret-moved") \
+    if extents:
+        [x, y, width, height] = extents
+    elif event and (event.type == "object:text-caret-moved") \
        and obj.text and (obj.text.caretOffset >= 0):
         offset = obj.text.caretOffset
         [x, y, width, height] = obj.text.getCharacterExtents(offset,
