@@ -1,6 +1,6 @@
 # Orca
 #
-# Copyright 2004-2006 Sun Microsystems Inc.
+# Copyright 2004-2007 Sun Microsystems Inc.
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Library General Public
@@ -19,10 +19,10 @@
 
 """The main module for the Orca screen reader."""
 
-__id__        = "$Id: orca.py 1818 2006-12-13 01:21:31Z wwalker $"
-__version__   = "$Revision: 1818 $"
-__date__      = "$Date: 2006-12-12 20:21:31 -0500 (Tue, 12 Dec 2006) $"
-__copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
+__id__        = "$Id: orca.py 2050 2007-02-25 22:40:48Z wwalker $"
+__version__   = "$Revision: 2050 $"
+__date__      = "$Date: 2007-02-25 17:40:48 -0500 (Sun, 25 Feb 2007) $"
+__copyright__ = "Copyright (c) 2005-2007 Sun Microsystems Inc."
 __license__   = "LGPL"
 
 # We're going to force the name of the app to "orca" so pygtk
@@ -1190,13 +1190,15 @@ def shutdownOnSignal(signum, frame):
             #
             speech.shutdown()
             shutdown()
+        cleanExit = True
     except:
-        pass
+        cleanExit = False
 
     if settings.timeoutCallback and (settings.timeoutTime > 0):
         signal.alarm(0)
 
-    abort(signum)
+    if not cleanExit:
+        abort(signum)
 
 def abortOnSignal(signum, frame):
     debug.println(debug.LEVEL_ALL,
