@@ -19,9 +19,9 @@
 
 """Custom script for Evolution."""
 
-__id__        = "$Id: Evolution.py,v 1.74 2006/11/20 19:21:57 richb Exp $"
-__version__   = "$Revision: 1.74 $"
-__date__      = "$Date: 2006/11/20 19:21:57 $"
+__id__        = "$Id: Evolution.py 1866 2006-12-28 18:53:39Z richb $"
+__version__   = "$Revision: 1866 $"
+__date__      = "$Date: 2006-12-28 13:53:39 -0500 (Thu, 28 Dec 2006) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -116,7 +116,7 @@ class Script(default.Script):
         self.inputEventHandlers["toggleReadMailHandler"] = \
             input_event.InputEventHandler(
                 Script.toggleReadMail,
-                _("Toggle whether we present new mail if we not not the active script."))
+                _("Toggle whether we present new mail if we are not the active script."))
 
     def getKeyBindings(self):
         """Defines the new key binding for this script. Setup the default
@@ -395,9 +395,13 @@ class Script(default.Script):
             if self.speakNewLine(event.source):
                 speech.speak(chnames.getCharacterName("\n"), None, False)
  
-            speech.speak(line, None, False)
+            if self.speakBlankLine(event.source):
+                speech.speak(_("blank"), None, False)
+            else:
+                speech.speak(line, None, False)
 
             return
+        
 
         # 2) Mail view: current message pane: "standard" mail header lines.
         #
@@ -538,6 +542,13 @@ class Script(default.Script):
                     # is, then to reduce verbosity, only speak and braille it,
                     # if it's checked or if we are moving the focus from to the
                     # left or right on the same row.
+                    #
+                    # The one exception to the above is if this is for the
+                    # Status checkbox, in which case we speake/braille it if
+                    # the message is unread (not checked).
+                    #
+                    header_obj = parent.table.getColumnHeader(i)
+                    header = atspi.Accessible.makeAccessible(header_obj)
 
                     checkbox = False
                     toRead = True
@@ -548,16 +559,18 @@ class Script(default.Script):
                                 checkbox = True
                                 checked = cell.state.count( \
                                     atspi.Accessibility.STATE_CHECKED)
-                                if not checked and speakAll:
-                                    toRead = False
+                                if speakAll:
+                                    if header.name == _("Status"):
+                                        toRead = not checked
+                                        break
+                                    if not checked:
+                                        toRead = False
                                 break
 
                     if toRead:
-                        obj = parent.table.getColumnHeader(i)
-                        header = atspi.Accessible.makeAccessible(obj)
-
                         # Speak/braille the column header for this table cell
                         # if it has focus (unless it's a checkbox).
+                        #
                         if not checkbox and verbose:
                             settings.brailleVerbosityLevel = \
                                 settings.VERBOSITY_LEVEL_BRIEF
@@ -595,7 +608,7 @@ class Script(default.Script):
                                            brailleGen.getBrailleRegions(cell)
 
                         if header.name == _("Status"):
-                            text = _("Read")
+                            text = _("unread")
                             utterances = [ text ]
                             brailleRegions.append(braille.Region(text))
                             brailleRegions.append(braille.Region(" "))
@@ -866,6 +879,10 @@ class Script(default.Script):
             if self.speakNewLine(event.source):
                 speech.speak(chnames.getCharacterName("\n"), None, False)
 
+
+            if self.speakBlankLine(event.source):
+                 speech.speak(_("blank"), None, False)
+
                 
         # 9) Spell Checking Dialog
         #
@@ -1050,7 +1067,31 @@ class Script(default.Script):
                     return True
 
         return False
+    def speakBlankLine(self, obj):
+        """Returns True if a blank line should be spoken.
+        Otherwise, returns False.
+        """
+        
+        # Get the the AccessibleText interrface. 
+        text = obj.text
+        if not text:
+            return False
 
+        # Get the line containing the caret
+        caretOffset = text.caretOffset
+        line = text.getTextAtOffset(caretOffset, \
+            atspi.Accessibility.TEXT_BOUNDARY_LINE_START)
+
+        debug.println(debug.LEVEL_FINEST, "speakBlankLine: start=%d, end=%d, line=<%s>" % (line[1], line[2], line[0]))
+
+        # If this is a blank line, announce it if the user requested
+        # that blank lines be spoken.
+        if line[1] == 0 and line[2] == 0:
+            return settings.speakBlankLines
+        else:
+            return False
+
+        
     def onStateChanged(self, event):
         """Called whenever an object's state changes.  We are only
         interested in "object:state-changed:showing" events for any
