@@ -21,9 +21,9 @@
 fallback to local settings if the user settings doesn't exist (e.g., in the
 case of gdm) or doesn't have the specified attribute."""
 
-__id__        = "$Id: settings.py,v 1.94 2006/12/13 01:21:31 wwalker Exp $"
-__version__   = "$Revision: 1.94 $"
-__date__      = "$Date: 2006/12/13 01:21:31 $"
+__id__        = "$Id: settings.py 2047 2007-02-23 01:52:09Z lmonsanto $"
+__version__   = "$Revision: 2047 $"
+__date__      = "$Date: 2007-02-22 20:52:09 -0500 (Thu, 22 Feb 2007) $"
 __copyright__ = "Copyright (c) 2005-2006 Sun Microsystems Inc."
 __license__   = "LGPL"
 
@@ -393,6 +393,7 @@ brailleBindingsMap      = {}
 # objects.
 #
 cacheValues             = True
+cacheDescriptions       = True
 
 # Script developer feature.  If False, no AT-SPI objects
 # will be cached locally.  Helps determine if there might be a
@@ -445,14 +446,6 @@ debugEventQueue         = False
 timeoutTime             = 10   # a value of 0 means don't do hang checking
 timeoutCallback         = None # Set by orca.py:init to orca.timeout
 
-# Assists with dealing with CORBA COMM_FAILURES.  A failure doesn't
-# always mean an object disappeared - there just might be a network
-# glitch.  So, on COMM_FAILURES, we might retry a few times before
-# giving up on an object.
-#
-commFailureWaitTime     = 0.1
-commFailureAttemptLimit = 5
-
 # Keyboard double-click period. If the same key is pressed within
 # this time period, it's considered to be a double-click and might
 # provide different functionality (for example, Numpad 5 double-click
